c**********************************************************************
c IO_INIT_PROPER.F
c**********************************************************************
c Read parameters of proper-elements filter. There are 5 variants
c of the filter:
c
c 1) Running averages of mean elements
c 2) Minimum/maximum filter for `resonant elements'
c 3) Running minimum/maximum of individual elements
c 4) Representative surface filter (another `res. el.')
c 5) Frequency Modified Fourier Transform
c    ref.: Sidlichovsky & Nesvorny (1997), Cel. Mech. 65, 137
c
c Author: Miroslav Broz, miroslav.broz@email.cz
c Date: May 9th 2003

      subroutine io_init_proper(infile,dtproper,outfile,iflgchk)

      include 'swift.inc'
      include 'filter.inc'
      include 'flt_cb.inc'
      include 'proper.inc'

c  input
      character*80 infile

c  output
      integer iflgchk
      real*8 dtproper
      character*80 outfile

c temporal variables
      integer i, j, k, iu, ierr
      real*8 dtoutfilter

c  functions
      integer read_i
      logical read_l
      real*8 read_f

c  executable code...
      iu = 7

c  read input parameters
      write(*,*) 'Proper parameters file called ',infile
      call io_open(iu,infile,'old','formatted',ierr)

      call read_s(iu,outfile)
      prop_ftype = read_i(iu)
      prop_writer8 = read_l(iu)

      dtproper = read_f(iu)

      prop_win = read_f(iu)
      prop_win = prop_win * 365.25d6
      prop_dt = read_f(iu)
      prop_dt = prop_dt * 365.25d6

      prop_ielmt = read_i(iu)
      prop_minmax = read_l(iu)      

      prop_mmel(1) = read_l(iu)
      prop_mmel(2) = read_l(iu)
      prop_mmel(3) = read_l(iu)

      prop_plid = read_i(iu)
      prop_p = read_i(iu)
      prop_q = read_i(iu)
      prop_sigma = read_f(iu)
      prop_sigma = prop_sigma / degrad
      prop_dsigma = read_f(iu)
      prop_dsigma = prop_dsigma / degrad
      prop_varpi = read_f(iu)
      prop_varpi = prop_varpi / degrad
      prop_dvarpi = read_f(iu)
      prop_dvarpi = prop_dvarpi / degrad
      prop_Omega = read_f(iu)
      prop_Omega = prop_Omega / degrad
      prop_dOmega = read_f(iu)
      prop_dOmega = prop_dOmega / degrad
      prop_sigmadot = read_i(iu)

      fmft_flag = read_i(iu)
      fmft_nfreq = read_i(iu)
      fmft_ndata = read_i(iu)
      fmft_writegs = read_l(iu)
      fmft_minf = read_f(iu)
      fmft_maxf = read_f(iu)
      fmft_freqsmall = read_f(iu)
      fmft_freqtoler = read_f(iu)
      fmft_nfreqknown = read_i(iu)

      if (fmft_nfreqknown.gt.MAX_FMFT_NFREQKNOWN) then
        write(*,40) fmft_nfreqknown,MAX_FMFT_NFREQKNOWN
40      format('Number of known frequencies ',i6,' have to be .lt. ',i6,
     :    ' (see proper.inc file)')
        call util_exit(1)
      endif
      do i = 1, fmft_nfreqknown
        fmft_freqknown(i) = read_f(iu)
      enddo

      close(unit = iu)
      write(*,*) ' '

c  check input parameters and available array dimensions

c  sampling time-step
      if (dtproper.lt.0.d0) then
        dtproper = dtfilter
      endif

c  mean elements output time-step
      k = 1
      do i = 1, filter_N
        k = k * filter_D(i)
      enddo
      dtoutfilter = k * dtfilter
      j = int(prop_win/dtoutfilter)
      if ((j.gt.PMAXN).and.(prop_ftype.le.3)) then
        write(*,20) prop_win/365.25d6,dtoutfilter/365.25d3,j,PMAXN
20      format('Running window width over mean element output (',f5.2,
     :    ' Myr/',f6.3,' kyr = ',i6,') have to be .lt. ',i6,
     :    ' (see proper.inc file)')
        call util_exit(1)
      endif

      if (fmft_ndata.gt.PMAXN) then
        write(*,30) fmft_ndata,PMAXN
30      format('Width of FMFT buffer ',i6,' have to be .lt. ',i6,
     :    ' (see proper.inc file)')
        call util_exit(1)
      endif

      return
      end	! io_init_proper.f

c-----------------------------------------------------------------

c****************************************************************
      subroutine read_s(iu, s)
c****************************************************************
      implicit none
      integer iu
      character*(*) s
c  functions
      integer length

5     continue
        read(iu, 10, end=20, err=20) s
10      format(a)
      if ((s(1:1).eq.'#').or.(length(s).eq.0)) goto 5
      return
20    continue
      write(*,*) 'read_s: Error reading input.'
      stop
      end

c****************************************************************
      integer function read_i(iu)
c****************************************************************
      implicit none
      integer iu
      character*255 s

      call read_s(iu, s)
      read(s, *, end=10, err=10) read_i
      return
10    continue
      write(*,*) 'read_i: Error reading input.'
      stop
      end

c****************************************************************
      real*8 function read_f(iu)
c****************************************************************
      implicit none
      integer iu
      character*255 s

      call read_s(iu, s)
      read(s, *, end=10, err=10) read_f
      return
10    continue
      write(*,*) 'read_f: Error reading input.'
      stop
      end

c****************************************************************
      logical function read_l(iu)
c****************************************************************
      implicit none
      integer iu
      character*255 s

      call read_s(iu, s)
      read(s, *, end=10, err=10) read_l
      return
10    continue
      write(*,*) 'read_l: Error reading input.'
      stop
      end


